// -*- C++ -*-
/**
 * \file functional.h
 * This file is part of LyX, the document processor.
 * Licence details can be found in the file COPYING.
 *
 * \author Peter Kümmel
 *
 * Full author contact details are available in file CREDITS.
 */

#ifndef LYX_FUNCTIONAL_H
#define LYX_FUNCTIONAL_H

#include <functional>

namespace lyx
{
	using std::function;
}


#endif
